/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.nop;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.util.EcoreUtil;

import tools.descartes.dql.connector.ConnectorProvider;
import tools.descartes.dql.connector.ModelStructureQueryConnector;
import tools.descartes.dql.models.mapping.domain.DomainFactory;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.Resource;
import tools.descartes.dql.models.mapping.domain.Service;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class ModelStructureQueryConnectorImpl extends AbstractNopQueryConnector
		implements ModelStructureQueryConnector {

	private final DomainFactory domainFactory = DomainFactory.eINSTANCE;

	public ModelStructureQueryConnectorImpl() {

		log.info(ModelStructureQueryConnector.class.getName() + " initialized");
		log.info("Handling requests for performance meta-model family "
				+ getBundleProperty(ConnectorProvider.FAMILY_KEY));
	}

	private boolean isValidEntitiesRequest(final EntityMapping request) {
		return isValidRequest(request);
	}

	private boolean isValidProbesRequest(final EntityMapping request) {
		// TODO: Beautify
		return true;
	}

	private boolean isValidRequest(final EntityMapping request) {
		final List<Service> services = request.getServices();
		final List<Resource> resources = request.getResources();

		if (services.isEmpty() && resources.isEmpty() && !request.getModelLocation().isEmpty()) {
			log.info("Request validated");
			return true;
		}

		log.warn("Invalid request");
		return false;
	}

	@Override
	public EntityMapping requestDoF(final EntityMapping request) {
		return null;
	}

	@Override
	public EntityMapping requestEntities(final EntityMapping request) {
		final EntityMapping response = EcoreUtil.copy(request);
		final List<Service> services = response.getServices();
		final List<Resource> resources = response.getResources();

		log.info("LIST ENTITIES requested");

		// The incoming request shall not contain a listing
		if (!isValidEntitiesRequest(request)) {
			return null;
		}

		for (int i = 0; i < NUMBER_OF_ELEMENTS; i++) {
			services.add(createService(domainFactory, i));
			resources.add(createResource(domainFactory, i));
		}

		return response;
	}

	@Override
	public EntityMapping requestProbes(final EntityMapping request) {
		final EntityMapping response = EcoreUtil.copy(request);
		final ArrayList<Entity> entities = new ArrayList<Entity>();

		entities.addAll(response.getServices());
		entities.addAll(response.getResources());

		log.info("LIST METRICS requested");

		// The incoming request shall not contain a listing
		if (!isValidProbesRequest(request)) {
			return null;
		}

		for (final Entity entity : entities) {
			for (int j = 0; j < NUMBER_OF_ELEMENTS; j++) {
				final Probe aProbe = createStringProbe(domainFactory, j);
				final Probe bProbe = createDecimalProbe(domainFactory, j);
				final Probe cProbe = createContinuousSeriesProbe(domainFactory, j);
				final Probe dProbe = createDiscreteSeriesProbe(domainFactory, j);
				final Probe eProbe = createListOfContinuousSeriesProbe(domainFactory, j);
				final Probe fProbe = createOnlineSeriesProbe(domainFactory, j);
				final Probe gProbe = createProbeWithStatTypes(domainFactory, j);
				entity.getProbes().add(bProbe);
				entity.getProbes().add(aProbe);
				entity.getProbes().add(cProbe);
				entity.getProbes().add(dProbe);
				entity.getProbes().add(eProbe);
				entity.getProbes().add(fProbe);
				entity.getProbes().add(gProbe);
			}
		}

		return response;
	}

	private Probe createProbeWithStatTypes(DomainFactory domainFactory2, int j) {
		Probe p = domainFactory2.createProbe();
		p.setMetricName("metricWithStatTypes" + j);
		StatType st1 = domainFactory2.createStatType();
		st1.setTypeName("min");
		p.getStatTypes().add(st1);
		StatType st2 = domainFactory2.createStatType();
		st2.setTypeName("max");
		p.getStatTypes().add(st2);
		StatType st3 = domainFactory2.createStatType();
		st3.setTypeName("sample");
		p.getStatTypes().add(st3);
		return p;
	}

	@Override
	public boolean supportsDoFRequests() {
		return false;
	}

	@Override
	public boolean supportsEntityRequests() {
		return true;
	}

	@Override
	public boolean supportsProbeRequests() {
		return true;
	}

}
