/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector;

/**
 * This class is exposed by a connector to provide an entry point of creating
 * instances of query connectors for specific query classes
 * 
 * @author Fabian Gorsler <fabian.gorsler@student.kit.edu>
 */
public interface ConnectorProvider {
	/**
	 * Name of the connector properties file
	 */
	public static String PROPERTIES_FILE = "META-INF/connector.properties";

	/**
	 * The property key for the name of the performance meta-model family
	 * supported
	 */
	public static String FAMILY_KEY = "dql.connector.family";

	/**
	 * The property key for indicating support of the model structure query
	 * class
	 */
	public static String MODEL_STRUCTURE_SUPPORT_KEY = "dql.connector.modelstructure";

	/**
	 * The property key for indicating support of the performance metrics query
	 * class
	 */
	public static String PERFORMANCE_METRICS_SUPPORT_KEY = "dql.connector.performancemetrics";

	/**
	 * The property key for indicating support of the performance issues query
	 * class
	 */
	public static String PERFORMANCE_ISSUES_SUPPORT_KEY = "dql.connector.performanceissues";

	/**
	 * Instantiate a ModelStructureQueryConnector
	 * 
	 * @see ModelStructureQueryConnector
	 * @return An instance of {@link ModelStructureQueryConnector}
	 */
	public ModelStructureQueryConnector createModelStructureQueryConnectorInstance();

	/**
	 * Instantiate a PerformanceIssueQueryConnector
	 * 
	 * @see PerformanceIssueQueryConnector
	 * @return An instance of {@link PerformanceIssueQueryConnector}
	 */
	public PerformanceIssueQueryConnector createPerformanceIssueQueryConnectorInstance();

	/**
	 * Instantiate a PerformanceMetricsQueryConnector
	 * 
	 * @see PerformanceMetricsQueryConnector
	 * @return An instance of {@link PerformanceMetricsQueryConnector}
	 */
	public PerformanceMetricsQueryConnector createPerformanceMetricsQueryConnectorInstance();
}
