package tools.descartes.dql.lang.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import tools.descartes.dql.lang.descartesQL.AbsoluteTimeClause;
import tools.descartes.dql.lang.descartesQL.AggregateMetricClause;
import tools.descartes.dql.lang.descartesQL.AliasClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertiesClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertyClause;
import tools.descartes.dql.lang.descartesQL.ConnectorInstanceReferenceClause;
import tools.descartes.dql.lang.descartesQL.ConnectorTimeUnitClause;
import tools.descartes.dql.lang.descartesQL.ConstraintClause;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.DescartesQLPackage;
import tools.descartes.dql.lang.descartesQL.DetectBottlenecksQuery;
import tools.descartes.dql.lang.descartesQL.DetectQuery;
import tools.descartes.dql.lang.descartesQL.DoFClause;
import tools.descartes.dql.lang.descartesQL.DoFReference;
import tools.descartes.dql.lang.descartesQL.DoFVariationClause;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.EntityReferenceClause;
import tools.descartes.dql.lang.descartesQL.ExplorationStrategyClause;
import tools.descartes.dql.lang.descartesQL.FilterClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionValue;
import tools.descartes.dql.lang.descartesQL.ForClause;
import tools.descartes.dql.lang.descartesQL.GetConstraintsQuery;
import tools.descartes.dql.lang.descartesQL.GetExplorationStrategiesQuery;
import tools.descartes.dql.lang.descartesQL.GetQuery;
import tools.descartes.dql.lang.descartesQL.GetTimeUnitsQuery;
import tools.descartes.dql.lang.descartesQL.IntervalVariationClause;
import tools.descartes.dql.lang.descartesQL.ListDoFQuery;
import tools.descartes.dql.lang.descartesQL.ListEntitiesQuery;
import tools.descartes.dql.lang.descartesQL.ListMetricsQuery;
import tools.descartes.dql.lang.descartesQL.ListQuery;
import tools.descartes.dql.lang.descartesQL.ListResourcesQuery;
import tools.descartes.dql.lang.descartesQL.ListServicesQuery;
import tools.descartes.dql.lang.descartesQL.MetricClause;
import tools.descartes.dql.lang.descartesQL.MetricClauses;
import tools.descartes.dql.lang.descartesQL.MetricReference;
import tools.descartes.dql.lang.descartesQL.MetricReferenceClauses;
import tools.descartes.dql.lang.descartesQL.MetricStarClause;
import tools.descartes.dql.lang.descartesQL.ModelFamily;
import tools.descartes.dql.lang.descartesQL.ModelLocation;
import tools.descartes.dql.lang.descartesQL.ModelReferenceClause;
import tools.descartes.dql.lang.descartesQL.ObserveBetweenClause;
import tools.descartes.dql.lang.descartesQL.ObserveClause;
import tools.descartes.dql.lang.descartesQL.ObserveRelativeClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeDurationClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeWithSignClause;
import tools.descartes.dql.lang.descartesQL.SampleClause;
import tools.descartes.dql.lang.descartesQL.SelectQuery;
import tools.descartes.dql.lang.descartesQL.UsingClause;
import tools.descartes.dql.lang.descartesQL.ValueVariationClause;
import tools.descartes.dql.lang.descartesQL.VaryingClause;
import tools.descartes.dql.lang.descartesQL.WithClause;
import tools.descartes.dql.lang.services.DescartesQLGrammarAccess;

@SuppressWarnings("all")
public class DescartesQLSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private DescartesQLGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == DescartesQLPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case DescartesQLPackage.ABSOLUTE_TIME_CLAUSE:
				if(context == grammarAccess.getAbsoluteTimeClauseRule() ||
				   context == grammarAccess.getBetweenTimeClauseRule() ||
				   context == grammarAccess.getTimeClauseRule()) {
					sequence_AbsoluteTimeClause(context, (AbsoluteTimeClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.AGGREGATE_METRIC_CLAUSE:
				if(context == grammarAccess.getAggregateMetricClauseRule() ||
				   context == grammarAccess.getMetricClauseTypeRule()) {
					sequence_AggregateMetricClause(context, (AggregateMetricClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.ALIAS_CLAUSE:
				if(context == grammarAccess.getAliasClauseRule()) {
					sequence_AliasClause(context, (AliasClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.CONFIGURATION_PROPERTIES_CLAUSE:
				if(context == grammarAccess.getConfigurationPropertiesClauseRule()) {
					sequence_ConfigurationPropertiesClause(context, (ConfigurationPropertiesClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.CONFIGURATION_PROPERTY_CLAUSE:
				if(context == grammarAccess.getConfigurationPropertyClauseRule()) {
					sequence_ConfigurationPropertyClause(context, (ConfigurationPropertyClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.CONNECTOR_INSTANCE_REFERENCE_CLAUSE:
				if(context == grammarAccess.getConnectorInstanceReferenceClauseRule() ||
				   context == grammarAccess.getObservationClauseRule()) {
					sequence_ConnectorInstanceReferenceClause(context, (ConnectorInstanceReferenceClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.CONNECTOR_TIME_UNIT_CLAUSE:
				if(context == grammarAccess.getConnectorTimeUnitClauseRule() ||
				   context == grammarAccess.getObservationClauseRule()) {
					sequence_ConnectorTimeUnitClause(context, (ConnectorTimeUnitClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.CONSTRAINT_CLAUSE:
				if(context == grammarAccess.getConstraintClauseRule()) {
					sequence_ConstraintClause(context, (ConstraintClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DESCARTES_QL:
				if(context == grammarAccess.getDescartesQLRule()) {
					sequence_DescartesQL(context, (DescartesQL) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DETECT_BOTTLENECKS_QUERY:
				if(context == grammarAccess.getDetectBottlenecksQueryRule()) {
					sequence_DetectBottlenecksQuery(context, (DetectBottlenecksQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DETECT_QUERY:
				if(context == grammarAccess.getDetectQueryRule() ||
				   context == grammarAccess.getPerformanceIssueQueryRule()) {
					sequence_DetectQuery(context, (DetectQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DO_FCLAUSE:
				if(context == grammarAccess.getDoFClauseRule()) {
					sequence_DoFClause(context, (DoFClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DO_FREFERENCE:
				if(context == grammarAccess.getDoFReferenceRule()) {
					sequence_DoFReference(context, (DoFReference) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.DO_FVARIATION_CLAUSE:
				if(context == grammarAccess.getDoFVariationClauseRule()) {
					sequence_DoFVariationClause(context, (DoFVariationClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.ENTITY_REFERENCE:
				if(context == grammarAccess.getEntityReferenceRule()) {
					sequence_EntityReference(context, (EntityReference) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.ENTITY_REFERENCE_CLAUSE:
				if(context == grammarAccess.getEntityReferenceClauseRule()) {
					sequence_EntityReferenceClause(context, (EntityReferenceClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.EXPLORATION_STRATEGY_CLAUSE:
				if(context == grammarAccess.getExplorationStrategyClauseRule()) {
					sequence_ExplorationStrategyClause(context, (ExplorationStrategyClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.FILTER_CLAUSE:
				if(context == grammarAccess.getFilterClauseRule()) {
					sequence_FilterClause(context, (FilterClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.FILTER_CONDITION_CLAUSE:
				if(context == grammarAccess.getFilterConditionClauseRule()) {
					sequence_FilterConditionClause(context, (FilterConditionClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.FILTER_CONDITION_VALUE:
				if(context == grammarAccess.getFilterConditionValueRule()) {
					sequence_FilterConditionValue(context, (FilterConditionValue) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.FOR_CLAUSE:
				if(context == grammarAccess.getForClauseRule()) {
					sequence_ForClause(context, (ForClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.GET_CONSTRAINTS_QUERY:
				if(context == grammarAccess.getGetConstraintsQueryRule()) {
					sequence_GetConstraintsQuery(context, (GetConstraintsQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.GET_EXPLORATION_STRATEGIES_QUERY:
				if(context == grammarAccess.getGetExplorationStrategiesQueryRule()) {
					sequence_GetExplorationStrategiesQuery(context, (GetExplorationStrategiesQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.GET_QUERY:
				if(context == grammarAccess.getConnectorCapabilityQueryRule() ||
				   context == grammarAccess.getGetQueryRule()) {
					sequence_GetQuery(context, (GetQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.GET_TIME_UNITS_QUERY:
				if(context == grammarAccess.getGetTimeUnitsQueryRule()) {
					sequence_GetTimeUnitsQuery(context, (GetTimeUnitsQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.INTERVAL_VARIATION_CLAUSE:
				if(context == grammarAccess.getIntervalVariationClauseRule()) {
					sequence_IntervalVariationClause(context, (IntervalVariationClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_DO_FQUERY:
				if(context == grammarAccess.getListDoFQueryRule()) {
					sequence_ListDoFQuery(context, (ListDoFQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_ENTITIES_QUERY:
				if(context == grammarAccess.getListEntitiesQueryRule()) {
					sequence_ListEntitiesQuery(context, (ListEntitiesQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_METRICS_QUERY:
				if(context == grammarAccess.getListMetricsQueryRule()) {
					sequence_ListMetricsQuery(context, (ListMetricsQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_QUERY:
				if(context == grammarAccess.getListQueryRule() ||
				   context == grammarAccess.getModelStructureQueryRule()) {
					sequence_ListQuery(context, (ListQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_RESOURCES_QUERY:
				if(context == grammarAccess.getListResourcesQueryRule()) {
					sequence_ListResourcesQuery(context, (ListResourcesQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.LIST_SERVICES_QUERY:
				if(context == grammarAccess.getListServicesQueryRule()) {
					sequence_ListServicesQuery(context, (ListServicesQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.METRIC_CLAUSE:
				if(context == grammarAccess.getMetricClauseRule() ||
				   context == grammarAccess.getMetricClauseTypeRule()) {
					sequence_MetricClause(context, (MetricClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.METRIC_CLAUSES:
				if(context == grammarAccess.getMetricClausesRule()) {
					sequence_MetricClauses(context, (MetricClauses) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.METRIC_REFERENCE:
				if(context == grammarAccess.getMetricReferenceRule()) {
					sequence_MetricReference(context, (MetricReference) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.METRIC_REFERENCE_CLAUSES:
				if(context == grammarAccess.getMetricReferenceClausesRule()) {
					sequence_MetricReferenceClauses(context, (MetricReferenceClauses) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.METRIC_STAR_CLAUSE:
				if(context == grammarAccess.getMetricStarClauseRule()) {
					sequence_MetricStarClause(context, (MetricStarClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.MODEL_FAMILY:
				if(context == grammarAccess.getModelFamilyRule()) {
					sequence_ModelFamily(context, (ModelFamily) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.MODEL_LOCATION:
				if(context == grammarAccess.getModelLocationRule()) {
					sequence_ModelLocation(context, (ModelLocation) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.MODEL_REFERENCE_CLAUSE:
				if(context == grammarAccess.getModelReferenceClauseRule()) {
					sequence_ModelReferenceClause(context, (ModelReferenceClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.OBSERVE_BETWEEN_CLAUSE:
				if(context == grammarAccess.getObservationClauseRule() ||
				   context == grammarAccess.getObserveBetweenClauseRule()) {
					sequence_ObserveBetweenClause(context, (ObserveBetweenClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.OBSERVE_CLAUSE:
				if(context == grammarAccess.getObserveClauseRule()) {
					sequence_ObserveClause(context, (ObserveClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.OBSERVE_RELATIVE_CLAUSE:
				if(context == grammarAccess.getObservationClauseRule() ||
				   context == grammarAccess.getObserveRelativeClauseRule()) {
					sequence_ObserveRelativeClause(context, (ObserveRelativeClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.RELATIVE_TIME_CLAUSE:
				if(context == grammarAccess.getRelativeTimeClauseRule() ||
				   context == grammarAccess.getTimeClauseRule()) {
					sequence_RelativeTimeClause(context, (RelativeTimeClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.RELATIVE_TIME_DURATION_CLAUSE:
				if(context == grammarAccess.getRelativeTimeDurationClauseRule()) {
					sequence_RelativeTimeDurationClause(context, (RelativeTimeDurationClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.RELATIVE_TIME_WITH_SIGN_CLAUSE:
				if(context == grammarAccess.getBetweenTimeClauseRule() ||
				   context == grammarAccess.getRelativeTimeWithSignClauseRule()) {
					sequence_RelativeTimeWithSignClause(context, (RelativeTimeWithSignClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.SAMPLE_CLAUSE:
				if(context == grammarAccess.getSampleClauseRule()) {
					sequence_SampleClause(context, (SampleClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.SELECT_QUERY:
				if(context == grammarAccess.getPerformanceMetricsQueryRule() ||
				   context == grammarAccess.getSelectQueryRule()) {
					sequence_SelectQuery(context, (SelectQuery) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.USING_CLAUSE:
				if(context == grammarAccess.getUsingClauseRule()) {
					sequence_UsingClause(context, (UsingClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.VALUE_VARIATION_CLAUSE:
				if(context == grammarAccess.getValueVariationClauseRule()) {
					sequence_ValueVariationClause(context, (ValueVariationClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.VARYING_CLAUSE:
				if(context == grammarAccess.getVaryingClauseRule()) {
					sequence_VaryingClause(context, (VaryingClause) semanticObject); 
					return; 
				}
				else break;
			case DescartesQLPackage.WITH_CLAUSE:
				if(context == grammarAccess.getWithClauseRule()) {
					sequence_WithClause(context, (WithClause) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     timeSpec=STRING
	 */
	protected void sequence_AbsoluteTimeClause(EObject context, AbsoluteTimeClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ABSOLUTE_TIME_CLAUSE__TIME_SPEC) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ABSOLUTE_TIME_CLAUSE__TIME_SPEC));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getAbsoluteTimeClauseAccess().getTimeSpecSTRINGTerminalRuleCall_0(), semanticObject.getTimeSpec());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (function=StatisticalAggregateType (metrics=MetricStarClause | metrics=MetricClauses) properties=ConfigurationPropertiesClause?)
	 */
	protected void sequence_AggregateMetricClause(EObject context, AggregateMetricClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='AS' alias=ID)
	 */
	protected void sequence_AliasClause(EObject context, AliasClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__ALIAS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.ALIAS_CLAUSE__ALIAS));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getAliasClauseAccess().getModeASKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getAliasClauseAccess().getAliasIDTerminalRuleCall_1_0(), semanticObject.getAlias());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (mode1='[' properties+=ConfigurationPropertyClause properties+=ConfigurationPropertyClause* mode2=']')
	 */
	protected void sequence_ConfigurationPropertiesClause(EObject context, ConfigurationPropertiesClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (key+=ID key+=ID* value=STRING)
	 */
	protected void sequence_ConfigurationPropertyClause(EObject context, ConfigurationPropertyClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (type=ID identifier=STRING)
	 */
	protected void sequence_ConnectorInstanceReferenceClause(EObject context, ConnectorInstanceReferenceClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__TYPE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__IDENTIFIER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_INSTANCE_REFERENCE_CLAUSE__IDENTIFIER));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getConnectorInstanceReferenceClauseAccess().getTypeIDTerminalRuleCall_0_0(), semanticObject.getType());
		feeder.accept(grammarAccess.getConnectorInstanceReferenceClauseAccess().getIdentifierSTRINGTerminalRuleCall_1_0(), semanticObject.getIdentifier());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (count=INT timeIndicator=ID)
	 */
	protected void sequence_ConnectorTimeUnitClause(EObject context, ConnectorTimeUnitClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__COUNT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__COUNT));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__TIME_INDICATOR) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONNECTOR_TIME_UNIT_CLAUSE__TIME_INDICATOR));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getConnectorTimeUnitClauseAccess().getCountINTTerminalRuleCall_0_0(), semanticObject.getCount());
		feeder.accept(grammarAccess.getConnectorTimeUnitClauseAccess().getTimeIndicatorIDTerminalRuleCall_1_0(), semanticObject.getTimeIndicator());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     type=STRING
	 */
	protected void sequence_ConstraintClause(EObject context, ConstraintClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.CONSTRAINT_CLAUSE__TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.CONSTRAINT_CLAUSE__TYPE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getConstraintClauseAccess().getTypeSTRINGTerminalRuleCall_1_0(), semanticObject.getType());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (query=ModelStructureQuery | query=PerformanceMetricsQuery | query=PerformanceIssueQuery | query=ConnectorCapabilityQuery)
	 */
	protected void sequence_DescartesQL(EObject context, DescartesQL semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (dofClause=DoFClause usingClause=UsingClause)
	 */
	protected void sequence_DetectBottlenecksQuery(EObject context, DetectBottlenecksQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__DOF_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__DOF_CLAUSE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__USING_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_BOTTLENECKS_QUERY__USING_CLAUSE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getDetectBottlenecksQueryAccess().getDofClauseDoFClauseParserRuleCall_1_0(), semanticObject.getDofClause());
		feeder.accept(grammarAccess.getDetectBottlenecksQueryAccess().getUsingClauseUsingClauseParserRuleCall_2_0(), semanticObject.getUsingClause());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     queryType=DetectBottlenecksQuery
	 */
	protected void sequence_DetectQuery(EObject context, DetectQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.DETECT_QUERY__QUERY_TYPE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.DETECT_QUERY__QUERY_TYPE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getDetectQueryAccess().getQueryTypeDetectBottlenecksQueryParserRuleCall_1_0(), semanticObject.getQueryType());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         mode='EVALUATE DOF' 
	 *         varyingClause=VaryingClause? 
	 *         explorationStrategy=ExplorationStrategyClause? 
	 *         constraintClause=ConstraintClause? 
	 *         withClause=WithClause?
	 *     )
	 */
	protected void sequence_DoFClause(EObject context, DoFClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (doFIdentifier=STRING doFAliasClause=AliasClause? (doFVariationClause=ConfigurationPropertiesClause | doFVariationClause=DoFVariationClause)?)
	 */
	protected void sequence_DoFReference(EObject context, DoFReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode1='<' (variation=IntervalVariationClause | variation=ValueVariationClause) mode2='>')
	 */
	protected void sequence_DoFVariationClause(EObject context, DoFVariationClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (entityReferences+=EntityReference entityReferences+=EntityReference*)
	 */
	protected void sequence_EntityReferenceClause(EObject context, EntityReferenceClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (type=EntityType identifier=STRING alias=AliasClause?)
	 */
	protected void sequence_EntityReference(EObject context, EntityReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='GUIDED BY' name=STRING parameterClause=ConfigurationPropertiesClause?)
	 */
	protected void sequence_ExplorationStrategyClause(EObject context, ExplorationStrategyClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='FILTERED BY' filterConditions+=FilterConditionClause (filterConjunctions+=FilterConjunction filterConditions+=FilterConditionClause)*)
	 */
	protected void sequence_FilterClause(EObject context, FilterClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='CONDITION' condition=FilterConditionType value=FilterConditionValue)
	 */
	protected void sequence_FilterConditionClause(EObject context, FilterConditionClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__CONDITION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__CONDITION));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_CLAUSE__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getModeCONDITIONKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getConditionFilterConditionTypeEnumRuleCall_2_0(), semanticObject.getCondition());
		feeder.accept(grammarAccess.getFilterConditionClauseAccess().getValueFilterConditionValueParserRuleCall_4_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     value=STRING
	 */
	protected void sequence_FilterConditionValue(EObject context, FilterConditionValue semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_VALUE__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FILTER_CONDITION_VALUE__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getFilterConditionValueAccess().getValueSTRINGTerminalRuleCall_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (mode='FOR' entityReferenceClause=EntityReferenceClause)
	 */
	protected void sequence_ForClause(EObject context, ForClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__ENTITY_REFERENCE_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.FOR_CLAUSE__ENTITY_REFERENCE_CLAUSE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getForClauseAccess().getModeFORKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getForClauseAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0(), semanticObject.getEntityReferenceClause());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     mode='CONSTRAINTS'
	 */
	protected void sequence_GetConstraintsQuery(EObject context, GetConstraintsQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_CONSTRAINTS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_CONSTRAINTS_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getGetConstraintsQueryAccess().getModeCONSTRAINTSKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     mode='EXPLORATION STRATEGIES'
	 */
	protected void sequence_GetExplorationStrategiesQuery(EObject context, GetExplorationStrategiesQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_EXPLORATION_STRATEGIES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_EXPLORATION_STRATEGIES_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getGetExplorationStrategiesQueryAccess().getModeEXPLORATIONSTRATEGIESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     ((queryTape=GetExplorationStrategiesQuery | queryTape=GetTimeUnitsQuery | queryTape=GetConstraintsQuery) usingClause=UsingClause)
	 */
	protected void sequence_GetQuery(EObject context, GetQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     mode='TIME UNITS'
	 */
	protected void sequence_GetTimeUnitsQuery(EObject context, GetTimeUnitsQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.GET_TIME_UNITS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.GET_TIME_UNITS_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getGetTimeUnitsQueryAccess().getModeTIMEUNITSKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (start=INT end=INT step=INT)
	 */
	protected void sequence_IntervalVariationClause(EObject context, IntervalVariationClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__START) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__START));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__END) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__END));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__STEP) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.INTERVAL_VARIATION_CLAUSE__STEP));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getStartINTTerminalRuleCall_0_0(), semanticObject.getStart());
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getEndINTTerminalRuleCall_2_0(), semanticObject.getEnd());
		feeder.accept(grammarAccess.getIntervalVariationClauseAccess().getStepINTTerminalRuleCall_4_0(), semanticObject.getStep());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (mode='DOF' withClause=WithClause?)
	 */
	protected void sequence_ListDoFQuery(EObject context, ListDoFQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     mode='ENTITIES'
	 */
	protected void sequence_ListEntitiesQuery(EObject context, ListEntitiesQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_ENTITIES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_ENTITIES_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getListEntitiesQueryAccess().getModeENTITIESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (mode='METRICS' entityReferenceClause=EntityReferenceClause)
	 */
	protected void sequence_ListMetricsQuery(EObject context, ListMetricsQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__ENTITY_REFERENCE_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_METRICS_QUERY__ENTITY_REFERENCE_CLAUSE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getListMetricsQueryAccess().getModeMETRICSKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getListMetricsQueryAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0(), semanticObject.getEntityReferenceClause());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         (queryType=ListEntitiesQuery | queryType=ListResourcesQuery | queryType=ListServicesQuery | queryType=ListMetricsQuery | queryType=ListDoFQuery) 
	 *         filterClause=FilterClause? 
	 *         usingClause=UsingClause
	 *     )
	 */
	protected void sequence_ListQuery(EObject context, ListQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     mode='RESOURCES'
	 */
	protected void sequence_ListResourcesQuery(EObject context, ListResourcesQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_RESOURCES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_RESOURCES_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getListResourcesQueryAccess().getModeRESOURCESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     mode='SERVICES'
	 */
	protected void sequence_ListServicesQuery(EObject context, ListServicesQuery semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.LIST_SERVICES_QUERY__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.LIST_SERVICES_QUERY__MODE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getListServicesQueryAccess().getModeSERVICESKeyword_0(), semanticObject.getMode());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     metricReference=MetricReference
	 */
	protected void sequence_MetricClause(EObject context, MetricClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.METRIC_CLAUSE__METRIC_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.METRIC_CLAUSE__METRIC_REFERENCE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getMetricClauseAccess().getMetricReferenceMetricReferenceParserRuleCall_0(), semanticObject.getMetricReference());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (metrics+=MetricClause metrics+=MetricClause*)
	 */
	protected void sequence_MetricClauses(EObject context, MetricClauses semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (metricClauseTypes+=MetricClauseType metricClauseTypes+=MetricClauseType*)
	 */
	protected void sequence_MetricReferenceClauses(EObject context, MetricReferenceClauses semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (entityReference=ID separator='.' metricReference=ID (separatorv='.' statTypeReference=ID)?)
	 */
	protected void sequence_MetricReference(EObject context, MetricReference semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     metricName=ID
	 */
	protected void sequence_MetricStarClause(EObject context, MetricStarClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.METRIC_STAR_CLAUSE__METRIC_NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.METRIC_STAR_CLAUSE__METRIC_NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getMetricStarClauseAccess().getMetricNameIDTerminalRuleCall_1_0(), semanticObject.getMetricName());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     family=ID
	 */
	protected void sequence_ModelFamily(EObject context, ModelFamily semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_FAMILY__FAMILY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_FAMILY__FAMILY));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelFamilyAccess().getFamilyIDTerminalRuleCall_0(), semanticObject.getFamily());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     location=STRING
	 */
	protected void sequence_ModelLocation(EObject context, ModelLocation semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_LOCATION__LOCATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_LOCATION__LOCATION));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelLocationAccess().getLocationSTRINGTerminalRuleCall_0(), semanticObject.getLocation());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (family=ModelFamily model=ModelLocation)
	 */
	protected void sequence_ModelReferenceClause(EObject context, ModelReferenceClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__FAMILY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__FAMILY));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__MODEL) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.MODEL_REFERENCE_CLAUSE__MODEL));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelReferenceClauseAccess().getFamilyModelFamilyParserRuleCall_0_0(), semanticObject.getFamily());
		feeder.accept(grammarAccess.getModelReferenceClauseAccess().getModelModelLocationParserRuleCall_2_0(), semanticObject.getModel());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         mode1='BETWEEN' 
	 *         (startingTime=AbsoluteTimeClause | startingTime=RelativeTimeWithSignClause) 
	 *         mode2='AND' 
	 *         (endingTime=AbsoluteTimeClause | endingTime=RelativeTimeWithSignClause)
	 *     )
	 */
	protected void sequence_ObserveBetweenClause(EObject context, ObserveBetweenClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='OBSERVE' observation=ObservationClause sampleClause=SampleClause?)
	 */
	protected void sequence_ObserveClause(EObject context, ObserveClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (direction=ObserveRelativeDirectionType (timeTarget=AbsoluteTimeClause | timeTarget=RelativeTimeClause))
	 */
	protected void sequence_ObserveRelativeClause(EObject context, ObserveRelativeClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*)
	 */
	protected void sequence_RelativeTimeClause(EObject context, RelativeTimeClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (duration=INT timeModifier=TimeModifierType)
	 */
	protected void sequence_RelativeTimeDurationClause(EObject context, RelativeTimeDurationClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__DURATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__DURATION));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__TIME_MODIFIER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_DURATION_CLAUSE__TIME_MODIFIER));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getRelativeTimeDurationClauseAccess().getDurationINTTerminalRuleCall_0_0(), semanticObject.getDuration());
		feeder.accept(grammarAccess.getRelativeTimeDurationClauseAccess().getTimeModifierTimeModifierTypeEnumRuleCall_1_0(), semanticObject.getTimeModifier());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (sign=RelativeTimeSignType timeClause=RelativeTimeClause)
	 */
	protected void sequence_RelativeTimeWithSignClause(EObject context, RelativeTimeWithSignClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__SIGN) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__SIGN));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__TIME_CLAUSE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.RELATIVE_TIME_WITH_SIGN_CLAUSE__TIME_CLAUSE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getRelativeTimeWithSignClauseAccess().getSignRelativeTimeSignTypeEnumRuleCall_0_0(), semanticObject.getSign());
		feeder.accept(grammarAccess.getRelativeTimeWithSignClauseAccess().getTimeClauseRelativeTimeClauseParserRuleCall_1_0(), semanticObject.getTimeClause());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (mode='SAMPLED BY' durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*)
	 */
	protected void sequence_SampleClause(EObject context, SampleClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (
	 *         metricReferenceClauses=MetricReferenceClauses 
	 *         constraintClause=ConstraintClause? 
	 *         dofClause=DoFClause? 
	 *         forClause=ForClause 
	 *         usingClause=UsingClause 
	 *         observeClause=ObserveClause?
	 *     )
	 */
	protected void sequence_SelectQuery(EObject context, SelectQuery semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='USING' modelReference=ModelReferenceClause)
	 */
	protected void sequence_UsingClause(EObject context, UsingClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODEL_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.USING_CLAUSE__MODEL_REFERENCE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getUsingClauseAccess().getModeUSINGKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getUsingClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0(), semanticObject.getModelReference());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (value+=INT value+=INT*)
	 */
	protected void sequence_ValueVariationClause(EObject context, ValueVariationClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='VARYING' dofReferences+=DoFReference dofReferences+=DoFReference*)
	 */
	protected void sequence_VaryingClause(EObject context, VaryingClause semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (mode='WITH' modelReference=ModelReferenceClause)
	 */
	protected void sequence_WithClause(EObject context, WithClause semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODE));
			if(transientValues.isValueTransient(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODEL_REFERENCE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, DescartesQLPackage.Literals.WITH_CLAUSE__MODEL_REFERENCE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getWithClauseAccess().getModeWITHKeyword_0_0(), semanticObject.getMode());
		feeder.accept(grammarAccess.getWithClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0(), semanticObject.getModelReference());
		feeder.finish();
	}
}
