package tools.descartes.PAVO.draw;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.LineBorder;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.impl.AdapterImpl;
import org.eclipse.emf.common.util.EList;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.Marker;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.category.BoxAndWhiskerRenderer;
import org.jfree.chart.renderer.xy.ClusteredXYBarRenderer;
import org.jfree.chart.renderer.xy.XYBarRenderer;
import org.jfree.data.general.PieDataset;
import org.jfree.data.statistics.BoxAndWhiskerCategoryDataset;
import org.jfree.data.xy.XYDataset;
import org.jfree.ui.RectangleAnchor;
import org.jfree.ui.TextAnchor;

import tools.descartes.PAVO.types.BarChart;
import tools.descartes.PAVO.types.BoxPlot;
import tools.descartes.PAVO.types.EnumDiagramtype;
import tools.descartes.PAVO.types.IVisualizationType;
import tools.descartes.PAVO.types.LineChart;
import tools.descartes.PAVO.types.PieChart;
import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;
import tools.descartes.dql.models.mapping.domain.ContinuousSeriesResult;
import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.DiscreteSeriesResult;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.OnlineResult;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.Result;
import tools.descartes.dql.models.mapping.domain.ResultList;
import tools.descartes.dql.models.mapping.domain.SeriesResultElement;
import tools.descartes.dql.models.mapping.domain.StringResult;


public class Visualizer {

	private JPanel frame = new JPanel(new BorderLayout());
	private JPanel visualizationPanel = new JPanel();
	
	private JPanel buttonPanel;	
	private JButton changeButton;
	private JButton exportButton;
	private JButton addAnalysis;
	private JComboBox<String> DiagramSwitchTypes;
	private Entity currentResource;


	private JFreeChart chart = null;
	private ChartPanel chartPanel = new ChartPanel(chart);
	private EnumDiagramtype currentDiagramType=EnumDiagramtype.NONE;
	private IVisualizationType currentData;

//	Probe currentProbe;
	private boolean chartShown=false;
	private JFileChooser c = new JFileChooser();
	
	//Variables for OnlinePlot
	private int DotsShown=0;
	private Result currentResult;
	int numberOnlineSeries;
	
	//Variables for DezMetric
	private boolean dezMetric=false;
	private List<String> nameDezMetric=new ArrayList<String>();
	private double dezValue;
	
	
	public Visualizer(Entity r) {
		
		BoxLayout layoutForViz = new BoxLayout(visualizationPanel, BoxLayout.Y_AXIS);
		visualizationPanel.setLayout(layoutForViz);
		frame.add(visualizationPanel, BorderLayout.CENTER);
		frame.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		frame.setVisible(true);
		
		buttonPanel = initializeButtons();
		frame.add(buttonPanel, BorderLayout.SOUTH);

		currentResource = r;
	}
	
	public JPanel initializeButtons()

	{
		changeButton = new JButton("Switch Diagram");
		changeButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				if (chartShown)
					transformDiagram();

			}
		});
		exportButton = new JButton("Export Diagram");
		exportButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
					exportDiagram();
			}
		});
		
		addAnalysis = new JButton("Show Analysis");
		addAnalysis.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				
				createAnalysisPanel();
				}
		});
		
		DiagramSwitchTypes = new JComboBox<String>();
		JPanel buttons = new JPanel();
		buttons.add(changeButton);
		buttons.add(DiagramSwitchTypes);
		buttons.add(exportButton);
		buttons.add(addAnalysis);
		
		return buttons;
	}
	
	public JPanel getCompletePanel()
	{
		frame.validate();
		return frame;
	}
	
	private void exportDiagram() {
		int a = c.showSaveDialog(null);
		if (a == JFileChooser.CANCEL_OPTION) {
			System.out.println("Canceled Save Action!");
		} else {
			final File file = c.getSelectedFile();
			String name = file.getPath();
			final File fileToUse;

			if (name.length() < 3 || !name.substring(name.length() - 3, name.length()).equals("png")) {
				fileToUse = new File(name + ".png");
			} else {
				fileToUse = file;
			}

			double c = (double) (chartPanel.getHeight());
			double b = (double) (chartPanel.getWidth());
			double faktorforWandH = c / b;

			final SelectExportSizeFrame select = new SelectExportSizeFrame(faktorforWandH);

			select.addWindowListener(new WindowListener() {

				@Override
				public void windowOpened(WindowEvent e) {
				}

				@Override
				public void windowIconified(WindowEvent e) {
				}

				@Override
				public void windowDeiconified(WindowEvent e) {
				}

				@Override
				public void windowDeactivated(WindowEvent e) {
				}

				@Override
				public void windowClosing(WindowEvent e) {
				}

				@Override
				public void windowClosed(WindowEvent e) {
					try {
						if (select.getSuccess() == true) {
							ChartUtilities.saveChartAsPNG(fileToUse, chart, select.getWidthFromText(),
									select.getHeightFromText());
						}

					} catch (IOException e1) {
					}

				}

				@Override
				public void windowActivated(WindowEvent e) {
				}
			});
		}

	}

	public void interpreteResource() {		
		for(Probe currentProbe : currentResource.getProbes())
		{
				if (currentProbe instanceof DecimalResult) {				
					JLabel labelZahl = new JLabel("Value of "+((DecimalResult) currentProbe).getValue().toString()+" for "+currentProbe.getMetricName());
					labelZahl.setBackground(Color.WHITE);
					labelZahl.setOpaque(true);
					visualizationPanel.add(labelZahl);
					visualizationPanel.add(new JLabel("    "));
					dezMetric = true;
					nameDezMetric.add(currentProbe.getMetricName());
					dezValue = ((DecimalResult) currentProbe).getValue().doubleValue();
					
				} else if (currentProbe instanceof StringResult) {
					
					JLabel labelString = new JLabel(((StringResult) currentProbe).getValue().toString()+" for "+currentProbe.getMetricName());
					labelString.setBackground(Color.WHITE);
					labelString.setOpaque(true);
					visualizationPanel.add(labelString);
					visualizationPanel.add(new JLabel("    "));
				}

				
				else if (currentProbe instanceof DiscreteSeriesResult) {
					
					chartShown = true;
					EList<SeriesResultElement> list = ((DiscreteSeriesResult) currentProbe).getElements();
					List<Double> x = new ArrayList<Double>();
					List<Double> y = new ArrayList<Double>();
					for (SeriesResultElement r : list) {
						x.add(r.getX().doubleValue());
						y.add(r.getY().doubleValue());
					}
					
					List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
					for(SeriesResultElement r : list)
					{
						confidences.add(r.getConfidenceInterval());
					}
					
					switch(currentDiagramType)
					{
					case NONE:
						currentData = BarChart.createSingleSeriesBarChart("", ((DiscreteSeriesResult) currentProbe).getXAxisDescription(),((DiscreteSeriesResult) currentProbe).getYAxisDescription(),currentProbe.getMetricName(), x,y, confidences);
						currentDiagramType = EnumDiagramtype.BARCHART;
						break;
					case LINECHART:
						((LineChart) currentData).addSeriesToChart(x, y,currentProbe.getMetricName(), confidences);
						break;	
					case BARCHART:
						((BarChart) currentData).addSeriesToChart(x, y, currentProbe.getMetricName(), confidences);
						break;
					default:
						break;
					}
					currentDiagramType = EnumDiagramtype.BARCHART;
			
				}
				
				

				else if (currentProbe instanceof ContinuousSeriesResult) {
					
					chartShown = true;
					EList<SeriesResultElement> list = ((ContinuousSeriesResult) currentProbe).getElements();
					List<Double> x = new ArrayList<Double>();
					List<Double> y = new ArrayList<Double>();
					for (SeriesResultElement r : list) {
						x.add(r.getX().doubleValue());
						y.add(r.getY().doubleValue());
					}
					
					List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
					for(SeriesResultElement r : list)
					{
						confidences.add(r.getConfidenceInterval());
					}
					
					switch(currentDiagramType)
					{
					case NONE:
						currentData = LineChart.createSingleSeriesLineChart("",((ContinuousSeriesResult) currentProbe).getXAxisDescription(),((ContinuousSeriesResult) currentProbe).getYAxisDescription(), currentProbe.getMetricName(), x, y, confidences );
						currentDiagramType = EnumDiagramtype.LINECHART;
						break;
					case LINECHART:
						((LineChart) currentData).addSeriesToChart(x, y, currentProbe.getMetricName(), confidences);
						break;	
					case BARCHART:
						((BarChart) currentData).addSeriesToChart(x, y, currentProbe.getMetricName(), confidences);
						break;
					default:
						break;
					}
					currentDiagramType = EnumDiagramtype.LINECHART;
					


				} 
				else if (currentProbe instanceof ResultList<?>) {
					chartShown = true;
					
					List<List<Double>> xWerte = new ArrayList<List<Double>>();
					List<List<Double>> yWerte = new ArrayList<List<Double>>();
					List<List<ConfidenceInterval>> confindencesN = new ArrayList<List<ConfidenceInterval>>();
					List<String> nameSeries = new ArrayList<String>();
					@SuppressWarnings("unchecked")
					String nameX = ((ResultList<ContinuousSeriesResult>)currentProbe).getResults().get(0).getXAxisDescription();
					@SuppressWarnings("unchecked")
					String nameY = ((ResultList<ContinuousSeriesResult>)currentProbe).getResults().get(0).getYAxisDescription();
					int i = 1;
					for(Result c : ((ResultList<?>) currentProbe).getResults())
					{
						
						EList<SeriesResultElement> list = ((ContinuousSeriesResult) c).getElements();
						List<Double> x = new ArrayList<Double>();
						List<Double> y = new ArrayList<Double>();
						List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
						for (SeriesResultElement r : list) {
							x.add(r.getX().doubleValue());
							y.add(r.getY().doubleValue());
							confidences.add(r.getConfidenceInterval());
						}
						xWerte.add(x);
						yWerte.add(y);
						nameSeries.add(currentProbe.getMetricName()+"Series Nr."+ i);
						confindencesN.add(confidences);
						i++;
						
					}
					switch(currentDiagramType)
					{
					case NONE:
						currentData = new LineChart("", nameX,nameY, xWerte, yWerte, nameSeries, confindencesN );
						break;
						
					case LINECHART:
						for(int a = 0; a < nameSeries.size(); a++)
						{
							((LineChart) currentData).addSeriesToChart
									(xWerte.get(a),
									yWerte.get(a),
									nameSeries.get(a),
									confindencesN.get(a));
						}
						
						break;	
						
					case BARCHART:
						for(int a = 0; a < nameSeries.size(); a++)
						{
							((BarChart) currentData).addSeriesToChart(xWerte.get(a),yWerte.get(a), nameSeries.get(a), confindencesN.get(a));
						}
						break;
						
					default:
						break;
					}	
					currentDiagramType = EnumDiagramtype.LINECHART;

				}
				else if(currentProbe instanceof OnlineResult){
					chartShown = true;
					changeButton.setVisible(false);
					DiagramSwitchTypes.setVisible(false);
				
					currentResult = ((OnlineResult) currentProbe).getResult();
			        
					switch(currentDiagramType)
					{
					case NONE:
						currentData = LineChart.createSingleSeriesLineChart("", ((ContinuousSeriesResult) currentResult).getXAxisDescription(),((ContinuousSeriesResult) currentResult).getYAxisDescription(),currentProbe.getMetricName(),new ArrayList<Double>(),new ArrayList<Double>(),new ArrayList<ConfidenceInterval>());
						numberOnlineSeries = 0;
						break;
					case LINECHART:
						((LineChart) currentData).addSeriesToChart(new ArrayList<Double>(), new ArrayList<Double>(), "Online Series by "+currentProbe.getMetricName(), new ArrayList<ConfidenceInterval>());
						numberOnlineSeries = currentData.getSeriesName().size()-1;
						break;
					case BARCHART:
						currentData=currentData.getLineChart();
						((LineChart) currentData).addSeriesToChart(new ArrayList<Double>(), new ArrayList<Double>(), "Online Series by "+currentProbe.getMetricName(), new ArrayList<ConfidenceInterval>());
						numberOnlineSeries = currentData.getSeriesName().size()-1;
						break;
					default:
						break;
					}
					
					

					
			       Adapter adapter = new AdapterImpl() {
					      public synchronized void notifyChanged(Notification notification) {
					    	  
					    	  	    
					    	    EList<SeriesResultElement> c = ((ContinuousSeriesResult) currentResult).getElements();
						        SeriesResultElement element = c.get(DotsShown);
						        ((LineChart) currentData).AddDotToSeries(numberOnlineSeries, element.getX().doubleValue(), element.getY().doubleValue(), element.getConfidenceInterval())	;				    
						        draw();					
						        DotsShown++;

					        
					        
					      }
					 };
					 currentResult.eAdapters().add(adapter);
				}
				
				else {
					changeButton.setEnabled(false);
					exportButton.setEnabled(false);
					DiagramSwitchTypes.setEnabled(false);

					JLabel error = new JLabel();
					
					error.setText(
							"Keinerlei Results zum Anzeigen verfuegbar! Weitere Ergebnisse bitte der unteren Tabelle entnehmen!");
					error.setBorder(new LineBorder(Color.RED, 5, true));
					visualizationPanel.add(error, BorderLayout.CENTER);
				}
		}

		this.checkButtons();
		this.draw();
		
			
	}
	
	public void checkButtons()
	{
		if(chartShown==false)
		{
			changeButton.setVisible(false);
			exportButton.setVisible(false);
			DiagramSwitchTypes.setVisible(false);
			addAnalysis.setVisible(false);
		}
	}
	
	public void draw() {
		if (currentData instanceof LineChart) {
			 chart = ChartFactory.createXYLineChart(currentData.getDiagramName(),
					 currentData.getxAxisLabel(), currentData.getyAxisLabel(), (XYDataset)currentData.getDataset(),PlotOrientation.VERTICAL, true,
						true, false);
			 if(dezMetric)
			 {
			 for(int i = 0; i < nameDezMetric.size(); i++)
			 {
				 Marker marker = new ValueMarker(dezValue);  // position is the value on the axis
				 marker.setPaint(Color.green);
				 marker.setLabel(nameDezMetric.get(i));
				 marker.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
				 marker.setLabelTextAnchor(TextAnchor.TOP_RIGHT);
				 ((XYPlot) chart.getPlot()).addRangeMarker(marker);
			 }	
			 }
			 
			
			currentDiagramType = EnumDiagramtype.LINECHART;
			
		} else if (currentData instanceof BoxPlot) {	
			
			  final BoxAndWhiskerCategoryDataset dataset1 = ((BoxPlot) currentData).getDataset();

		        final CategoryAxis xAxis = new CategoryAxis(currentData.getxAxisLabel());
		        final NumberAxis yAxis = new NumberAxis(currentData.getyAxisLabel());
		        yAxis.setAutoRangeIncludesZero(false);
		        BoxAndWhiskerRenderer renderer = new BoxAndWhiskerRenderer();
		        renderer.setMeanVisible(false);
		        CategoryPlot plot = new CategoryPlot(dataset1, xAxis, yAxis, renderer);

		        chart = new JFreeChart(
		            plot
		        );
			
			
//			chart = ChartFactory.createBoxAndWhiskerChart(currentData.getDiagramName(), "", "", ((BoxPlot) currentData).getDataset(),
//					true);
			
			currentDiagramType = EnumDiagramtype.BOXPLOT;

		} else if (currentData instanceof PieChart) {

			chart = ChartFactory.createPieChart(currentData.getDiagramName(), (PieDataset) currentData.getDataset(), true, // include
																												// legend
			true, false);
					currentDiagramType = EnumDiagramtype.PIECHART;

		} else if (currentData instanceof BarChart) {

			  NumberAxis domainAxis = new NumberAxis(currentData.getxAxisLabel());
			  domainAxis.setAutoRangeIncludesZero(false);

			  NumberAxis valueAxis = new NumberAxis(currentData.getyAxisLabel());

			  XYBarRenderer renderer = new ClusteredXYBarRenderer();
			  renderer.setMargin(0.5);
			  XYPlot plot = new XYPlot((XYDataset) currentData.getDataset(), domainAxis, valueAxis, renderer);
			  plot.setOrientation(PlotOrientation.VERTICAL);

			  chart = new JFreeChart("", JFreeChart.DEFAULT_TITLE_FONT, plot, true);
				
			  currentDiagramType = EnumDiagramtype.BARCHART;
		}

		fillComboBoxToDiagram();
		updateChart();

	}

	public void updateChart() {
		visualizationPanel.remove(chartPanel);
		chartPanel = new ChartPanel(chart);
		visualizationPanel.add(chartPanel, BorderLayout.CENTER);
		visualizationPanel.repaint();
		visualizationPanel.setVisible(true);

	}
	
	public void fillComboBoxToDiagram() {
		DiagramSwitchTypes.removeAllItems();
		if (currentDiagramType == EnumDiagramtype.LINECHART) {
			DiagramSwitchTypes.addItem("LineChart");
			DiagramSwitchTypes.addItem("BarChart");
			DiagramSwitchTypes.addItem("BarChart with Confidence Interval");
			DiagramSwitchTypes.addItem("LineChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BoxPlot");
		} else if (currentDiagramType == EnumDiagramtype.BARCHART) {
			DiagramSwitchTypes.addItem("BarChart");
			DiagramSwitchTypes.addItem("LineChart");
			DiagramSwitchTypes.addItem("LineChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BarChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BoxPlot");
		} else if (currentDiagramType == EnumDiagramtype.LINECHARTCONFIDENCE) {
			DiagramSwitchTypes.addItem("LineChart with Confidence Interval");
			DiagramSwitchTypes.addItem("LineChart");
			DiagramSwitchTypes.addItem("BarChart");
			DiagramSwitchTypes.addItem("BarChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BoxPlot");
		} else if (currentDiagramType == EnumDiagramtype.BARCHARTCONFIDENCE) {
			DiagramSwitchTypes.addItem("BarChart with Confidence Interval");
			DiagramSwitchTypes.addItem("LineChart");
			DiagramSwitchTypes.addItem("LineChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BarChart");
			DiagramSwitchTypes.addItem("BoxPlot");
		} else if (currentDiagramType == EnumDiagramtype.BOXPLOT) {
			DiagramSwitchTypes.addItem("BoxPlot");
			DiagramSwitchTypes.addItem("LineChart");
			DiagramSwitchTypes.addItem("LineChart with Confidence Interval");
			DiagramSwitchTypes.addItem("BarChart");
			DiagramSwitchTypes.addItem("BarChart with Confidence Interval");
		}
	}

	public void createAnalysisPanel()
	{
		JFrame popup = new JFrame("Analysis Popup");
		popup.setSize(400, 200);
		popup.add(new JLabel(currentData.getAnalysisResult()));
		popup.setVisible(true);
		popup.toFront();
		
		
	}
	

	
	public void transformDiagram() {
		String switchType = DiagramSwitchTypes.getSelectedItem().toString();;
		
		// switch case
			switch(switchType)
			{
			case "BarChart": 
				currentData = currentData.getBarChart();
				this.draw();
				break;
			case "LineChart with Confidence Interval":
				chart = currentData.getLineChart().drawConfidenceLine();
				currentDiagramType=EnumDiagramtype.LINECHARTCONFIDENCE;
				this.updateChart();
				this.fillComboBoxToDiagram();
				break;
			case "BarChart with Confidence Interval":
				chart = currentData.getBarChart().drawConfidenceBar();
				currentDiagramType=EnumDiagramtype.BARCHARTCONFIDENCE;
				this.updateChart();
				this.fillComboBoxToDiagram();
				break;
			case "LineChart":
				currentData=currentData.getLineChart();
				this.draw();
				break;
			case "BoxPlot":
				currentData=currentData.getBoxPlot();
				this.draw();
				break;
			}
	}
			
						
//			
//			
//		} else if (currentDiagramType == EnumDiagramtype.BARCHART) {
//			
//			
//			if (switchTo.equals("LineChart")) {
//				this.draw(currentData.getLineChart());
//			}
//			else if(switchTo.equals("LineChart with Confidence Interval"))
//			{
//				((LineChart) currentData).drawConfidenceLine();
//				currentDiagramType=EnumDiagramtype.LINECHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();
//				
//			}
//			else if(switchTo.equals("BarChart with Confidence Interval"))
//			{
//				((BarChart) currentData).drawConfidenceBar();
//		        currentDiagramType=EnumDiagramtype.BARCHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();
//			}
//			else if(switchTo.equals("BoxPlot"))
//			{
//				this.draw(currentData.getBoxPlot());
//			}
//		}
//		
//		
//		
//		else if (currentDiagramType == EnumDiagramtype.BOXPLOT) {
//			
//			switchTo = DiagramSwitchTypes.getSelectedItem().toString();
//			
//			if (switchTo.equals("LineChart") ){
//				this.draw(currentData.getLineChart());
//			}
//			else if(switchTo.equals("LineChart with Confidence Interval"))
//			{
//				((LineChart) currentData).drawConfidenceLine();
//				currentDiagramType=EnumDiagramtype.LINECHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();;
//			}
//			else if(switchTo.equals("BarChart"))
//			{
//				this.draw(currentData.getBarChart());
//			}
//			else if(switchTo.equals("BarChart with Confidence Interval"))
//			{
//				((BarChart) currentData).drawConfidenceBar();
//		        currentDiagramType=EnumDiagramtype.BARCHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();
//			}
//		}
//		
//		
//		
//		else if (currentDiagramType == EnumDiagramtype.BARCHARTCONFIDENCE) {
//			
//			switchTo = DiagramSwitchTypes.getSelectedItem().toString();
//			
//			if (switchTo.equals("LineChart") ){
//				this.draw(currentData.getLineChart());
//			}
//			else if(switchTo.equals("LineChart with Confidence Interval"))
//			{
//				((LineChart) currentData).drawConfidenceLine();
//				currentDiagramType=EnumDiagramtype.LINECHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();
//			}
//			else if(switchTo.equals("BarChart"))
//			{
//				this.draw(currentData.getBarChart());
//			}
//			else if(switchTo.equals("BoxPlot"))
//			{
//				this.draw(currentData.getBoxPlot());
//			}
//		}
//		
//		
//		
//		else if (currentDiagramType == EnumDiagramtype.LINECHARTCONFIDENCE) {
//			
//			switchTo = DiagramSwitchTypes.getSelectedItem().toString();
//			
//			if (switchTo.equals("BarChart")) {
//				this.draw(currentData.getBarChart());
//			}
//			else if(switchTo.equals("LineChart"))
//			{
//				this.draw(currentData.getLineChart());
//			}
//			else if(switchTo.equals("BarChart with Confidence Interval"))
//			{
//				((BarChart) currentData).drawConfidenceBar();
//		        currentDiagramType=EnumDiagramtype.BARCHARTCONFIDENCE;
//		        fillComboBoxToDiagram();
//		        updateChart();
//			}
//			else if(switchTo.equals("BoxPlot"))
//			{
//				this.draw(currentData.getBoxPlot());
//			}
//		}
//	}


}