/**
 * This interface declares all different kinds of Diagrams, which can be shown by this libry
 * 
 * @author Maximilian Koenig
 */
package tools.descartes.PAVO.types;

import java.util.ArrayList;
import java.util.List;

import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;


public abstract class AbstractVisualizationType implements IVisualizationType{

	 private String diagramName;
	 private String xAxisLabel;
	 private String yAxisLabel;
	
	 private List<List<Double>> yValues = new ArrayList<List<Double>>();
	 private List<List<Double>> xValues = new ArrayList<List<Double>>();
	 private List<String> seriesNames = new ArrayList<String>();
	 private List<List<ConfidenceInterval>> confidences = new ArrayList<List<ConfidenceInterval>>();
	
	public AbstractVisualizationType(){
		
	}
	
	public AbstractVisualizationType(String nameNeu, String XAxis, String yAxis,List<List<Double>> xValuesN, List<List<Double>> yValuesN, List<String> seriesNameN, List<List<ConfidenceInterval>> confidencesNeu){
		this.diagramName=nameNeu;
		this.xAxisLabel = XAxis;
		this.yAxisLabel = yAxis;
		this.xValues = xValuesN;
		this.yValues = yValuesN;
		this.seriesNames = seriesNameN;
		this.confidences= confidencesNeu;
	}
	
	public abstract LineChart getLineChart();
	public abstract BoxPlot getBoxPlot();
	public abstract BarChart getBarChart();
	
	@Override
	public String getDiagramName() {
		return diagramName;
	}
	@Override
	public void setDiagramName(String diagramName) {
		this.diagramName = diagramName;
	}
	
	@Override
	public double getMax(List<Double> list) {
		double max = list.get(0);
		for(double d : list)
		{
			if(d>max)
				max = d;
		}
		return max;
	}
	@Override
	public double getMin(List<Double> list) {
		double min = list.get(0);
		for(double d : list)
		{
			if(d<min)
				min = d;
		}
		return min;
	}
	@Override
	public double getMean(List<Double> list) {
		double mean = 0;
		int counter = 0;
		for(double d : list)
		{
			mean = mean + d;
			counter ++ ;
		}
		return mean/counter;
	}

	@Override
	public String getxAxisLabel() {
		return xAxisLabel;
	}

	@Override
	public void setxAxisLabel(String xAxisLabel) {
		this.xAxisLabel = xAxisLabel;
	}

	@Override
	public String getyAxisLabel() {
		return yAxisLabel;
	}

	@Override
	public void setyAxisLabel(String yAxisLabel) {
		this.yAxisLabel = yAxisLabel;
	}
	@Override
	public List<List<Double>> getyValues() {
		return yValues;
	}

	@Override
	public void setyValues(List<List<Double>> yValues) {
		this.yValues = yValues;
	}

	@Override
	public List<List<Double>> getxValues() {
		return xValues;
	}

	@Override
	public void setxValues(List<List<Double>> xValues) {
		this.xValues = xValues;
	}

	@Override
	public List<String> getSeriesName() {
		return seriesNames;
	}
	@Override
	public void setSeriesName(List<String> seriesName) {
		this.seriesNames = seriesName;
	}

	@Override
	public List<List<ConfidenceInterval>> getConfidences() {
		return confidences;
	}

	@Override
	public void setConfidences(List<List<ConfidenceInterval>> confidences) {
		this.confidences = confidences;
	}

	@Override
	public String toString() {
		return "VisualizationType [diagramName=" + diagramName + ", xAxisLabel=" + xAxisLabel + ", yAxisLabel="
				+ yAxisLabel + ", yValues=" + yValues + ", xValues=" + xValues + ", seriesName=" + seriesNames
				+ ", confidences=" + confidences + "]";
	}
	@Override
	public String getAnalysisResult()
	{
		String result = "";
		for(int i = 0; i< this.getSeriesName().size(); i++)
		{
			result += "<html><body>&nbsp;Name der Series: "+this.getSeriesName().get(i)+"<br>";
			result += "X-Values: <br>";
			result += "&nbsp;Maximum: "+ this.getMax(this.getxValues().get(i))+"<br> ";
			result += "&nbsp;Minimum: "+ this.getMin(this.getxValues().get(i))+"<br> ";
			result += "&nbsp;Mean: "+ this.getMean(this.getxValues().get(i))+"<br> ";
			
			result += "Y-Values: <br>";
			result += "&nbsp;Maximum: "+ this.getMax(this.getyValues().get(i))+"<br> ";
			result += "&nbsp;Minimum: "+ this.getMin(this.getyValues().get(i))+"<br> ";
			result += "&nbsp;Mean: "+ this.getMean(this.getyValues().get(i))+"<br> ";
			
		}
		result += "</body></html>";	
		return result;
	}
	
	
	
	
	
	

	
	
}