/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.PAVO.types;

import java.util.ArrayList;
import java.util.List;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.renderer.category.CategoryItemRenderer;
import org.jfree.chart.renderer.category.StatisticalBarRenderer;
import org.jfree.data.statistics.DefaultStatisticalCategoryDataset;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;

import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;


public class BarChart extends AbstractVisualizationType implements IVisualizationType{
	
	
	private  XYSeriesCollection dataset = new XYSeriesCollection();
	
	public BarChart(String nameNeu,String xNeu, String yNeu, List<String> seriesNameN, List<List<Double>> xValuesN, List<List<Double>> yValuesN, List<List<ConfidenceInterval>> confidencesN){
		super(nameNeu, xNeu, yNeu, xValuesN, yValuesN, seriesNameN, confidencesN);
		for(int i = 0; i<seriesNameN.size(); i++)
		{
			XYSeries series1 = new XYSeries(seriesNameN.get(i));
			for(int j=0;j<xValuesN.get(i).size(); j++)
			{
				series1.add(xValuesN.get(i).get(j), yValuesN.get(i).get(j));
			}		
			dataset.addSeries(series1);
		}

	
		
	}
	
	public static BarChart createSingleSeriesBarChart(String nameNeu,String xNeu, String yNeu, String seriesNameN, List<Double> xValuesN,List<Double> yValuesN, List<ConfidenceInterval> confidencesNeu){
		ArrayList<String> name = new ArrayList<String>();
		ArrayList<List<Double>> x = new ArrayList<List<Double>>();
		ArrayList<List<Double>> y = new ArrayList<List<Double>>();
		ArrayList<List<ConfidenceInterval>> confidencesN = new ArrayList<List<ConfidenceInterval>>();
		name.add(seriesNameN);
		x.add(xValuesN);
		y.add(yValuesN);
		confidencesN.add(confidencesNeu);
		
		return new BarChart(nameNeu, xNeu, yNeu, name, x,y,confidencesN);
	
		
	}
	

	public void addSeriesToChart( List<Double> xvaluesN, List<Double> yvaluesN, String seriesNameN, List<ConfidenceInterval> confidencesNeu )
	{
		//Noetig, da die erste Series bereits im Konstruktor hinzugefügt wird, die restlichen muessen hier zu den Attributen hinzugefuegt werden
		this.getSeriesName().add(seriesNameN);
		this.getxValues().add(xvaluesN);
		this.getyValues().add(yvaluesN);
		this.getConfidences().add(confidencesNeu);
		
		
		XYSeries series1 = new XYSeries(seriesNameN);
		for(int i=0;i<xvaluesN.size(); i++)
		{
			series1.add(xvaluesN.get(i), yvaluesN.get(i));
		}		
		dataset.addSeries(series1);
	}
	

	public JFreeChart drawConfidenceBar()
	{
		
		final DefaultStatisticalCategoryDataset result = new DefaultStatisticalCategoryDataset();
        for(int i = 0; i<this.getSeriesName().size(); i++)
        {
        	for(int j =0; j < this.getxValues().get(i).size(); j++)
        	{
        		result.add(this.getyValues().get(i).get(j), this.getConfidences().get(i).get(j).getIntervalHalfLength() ,this.getSeriesName().get(i) , this.getxValues().get(i).get(j));
        	}
        }
        CategoryAxis xAxis = new CategoryAxis(this.getxAxisLabel());
        final ValueAxis yAxis = new NumberAxis(this.getyAxisLabel());
        final CategoryItemRenderer renderer = new StatisticalBarRenderer();
        final CategoryPlot plot = new CategoryPlot(result, xAxis, yAxis, renderer);
        return new JFreeChart(this.getDiagramName(), JFreeChart.DEFAULT_TITLE_FONT, plot, true);

    	}

	/**
	 * @return the dataset
	 */
	public XYSeriesCollection getDataset() {
		return dataset;
	}

	/**
	 * @param dataset the dataset to set
	 */
	public void setDataset(XYSeriesCollection dataset) {
		this.dataset = dataset;
	}

	/**
	 * @return the xAxisLabel
	 */
	
	@Override
	public LineChart getLineChart() {
		System.out.println(this.getSeriesName().size());
		LineChart line = new LineChart(this.getDiagramName(), this.getxAxisLabel(), this.getyAxisLabel(), this.getxValues(), this.getyValues(), this.getSeriesName(), this.getConfidences());
		return line;
	}


	@Override
	public BoxPlot getBoxPlot() {
		BoxPlot box = new BoxPlot(this.getDiagramName(), this.getxAxisLabel(), this.getyAxisLabel(), this.getSeriesName(), this.getxValues(), this.getyValues(), this.getConfidences());
		return box;
	}


	@Override
	public PieChart getPieChart() {
		// TODO Auto-generated method stub
		return null;
	}


	@Override
	public BarChart getBarChart() {
		return this;
	}
	
	public void AddDotToSeries(int seriesNr, double x, double y, ConfidenceInterval confidence)
	{
		this.getxValues().get(seriesNr).add(x);
		this.getyValues().get(seriesNr).add(x);
		this.getConfidences().get(seriesNr).add(confidence);
		((XYSeries) dataset.getSeries().get(seriesNr)).add(x,y);
	}



	

	
}