/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.PAVO.types;


import java.util.ArrayList;

import java.util.List;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYErrorRenderer;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.data.xy.YIntervalSeries;
import org.jfree.data.xy.YIntervalSeriesCollection;

import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;

public class LineChart  extends AbstractVisualizationType implements IVisualizationType{
	
	private  XYSeriesCollection dataset = new XYSeriesCollection();
	
	
	public LineChart(String nameNeu,String xNameNeu,String yNameNeu, List<List<Double>> xvalueNeu, List<List<Double>> yvalueNeu, List<String> nameSeriesNeu, List<List<ConfidenceInterval>> confidencesNeu){
	
		super(nameNeu, xNameNeu, yNameNeu, xvalueNeu, yvalueNeu, nameSeriesNeu, confidencesNeu);

		for(int i = 0; i<nameSeriesNeu.size(); i++)
		{
			XYSeries series1 = new XYSeries(nameSeriesNeu.get(i));	
			for(int j = 0; j < xvalueNeu.get(i).size(); j++)
			{
				series1.add(xvalueNeu.get(i).get(j), yvalueNeu.get(i).get(j));
			}
			this.dataset.addSeries(series1);
		}

	}
	
	public static LineChart createSingleSeriesLineChart(String nameNeu,String xNeu, String yNeu, String seriesNameN, List<Double> xValuesN,List<Double> yValuesN, List<ConfidenceInterval> confidencesNeu){
		ArrayList<String> name = new ArrayList<String>();
		ArrayList<List<Double>> x = new ArrayList<List<Double>>();
		ArrayList<List<Double>> y = new ArrayList<List<Double>>();
		ArrayList<List<ConfidenceInterval>> confidencesN = new ArrayList<List<ConfidenceInterval>>();
		name.add(nameNeu);
		x.add(xValuesN);
		y.add(yValuesN);
		confidencesN.add(confidencesNeu);
		
		return new LineChart(nameNeu, xNeu, yNeu,  x,y,name,confidencesN);
	
		
	}
	
	public void AddDotToSeries(int seriesNr, double x, double y, ConfidenceInterval confidence)
	{
		this.getxValues().get(seriesNr).add(x);
		this.getyValues().get(seriesNr).add(x);
		this.getConfidences().get(seriesNr).add(confidence);
		((XYSeries) dataset.getSeries().get(seriesNr)).add(x,y);
	}
	
	public void addSeriesToChart(List<Double> xNeu, List<Double> yNeu, String nameSeriesNeu, List<ConfidenceInterval> confidencesNeu)
	{
		XYSeries series1 = new XYSeries(nameSeriesNeu);	
		this.getSeriesName().add(nameSeriesNeu);
		this.getxValues().add(xNeu);
		this.getyValues().add(yNeu);
		this.getConfidences().add(confidencesNeu);
		for(int i = 0; i < xNeu.size(); i++)
		{
			series1.add(xNeu.get(i), yNeu.get(i));
		}
		this.dataset.addSeries(series1);
	
	}

	public JFreeChart drawConfidenceLine()
	{
		YIntervalSeriesCollection dataset = new YIntervalSeriesCollection();
	     for(int i = 0; i <this.getSeriesName().size() ;i++)
	     {
	    	 YIntervalSeries s1 = new YIntervalSeries(this.getSeriesName().get(i));
	    	 for(int j = 0; j< this.getxValues().get(i).size() ;j++)
	    	 {
	    		 ConfidenceInterval c =  this.getConfidences().get(i).get(j);
	    		 Double x = this.getxValues().get(i).get(j);
	    		 Double y = this.getyValues().get(i).get(j);
	    		 s1.add(x, y, y-c.getIntervalHalfLength().doubleValue(), y+c.getIntervalHalfLength().doubleValue());
	    	 }
		     dataset.addSeries(s1);
	     }
		
	   NumberAxis xAxis = new NumberAxis(((LineChart) this).getxAxisLabel());
       NumberAxis yAxis = new NumberAxis(((LineChart) this).getyAxisLabel());
       XYErrorRenderer renderer = new XYErrorRenderer();
       renderer.setBaseLinesVisible(true);
       renderer.setBaseShapesVisible(false);
       XYPlot plot = new XYPlot(dataset, xAxis, yAxis, renderer);

       
      return  new JFreeChart("", plot);
      
	}
	
	

	

	public XYSeriesCollection getDataset()
	{
		return dataset;
	}
	
	/**
	 * @return the confidences
	 */

	@Override
	public LineChart getLineChart() {
		return this;
	}

	@Override
	public BoxPlot getBoxPlot() {
		BoxPlot box = new BoxPlot(this.getDiagramName(), this.getxAxisLabel(), this.getyAxisLabel(), this.getSeriesName(), this.getxValues(), this.getyValues(), this.getConfidences());
		return box;
	}

	@Override
	public PieChart getPieChart() {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public BarChart getBarChart() {
		BarChart bar = new BarChart(this.getDiagramName(), this.getxAxisLabel(), this.getyAxisLabel(), this.getSeriesName(),  this.getxValues(), this.getyValues(), this.getConfidences());
		return bar;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return super.toString()+"LineChart [confidences=" + this.getConfidences() + ", dataset=" + dataset + "]";
	}
	
	



	
	
	

	
}